import { ActivatedRoute, Data, Params, Route, UrlSegment } from '@angular/router';
/**
 * The options that are passed when creating an ActivatedRouteStub.
 */
export interface ActivatedRouteStubOptions {
    /**
     * The initial values of the parameters of the route
     */
    params?: Params;
    /**
     * The initial values of the query parameters of the route
     */
    queryParams?: Params;
    /**
     * The initial values of the data of the route
     */
    data?: Data;
    /**
     * The initial values of the title of the route
     */
    title?: string;
    /**
     * The initial fragment of the route
     */
    fragment?: string | null;
    /**
     * The initial url of the route
     */
    url?: UrlSegment[];
    /**
     * The parent of the route
     */
    parent?: ActivatedRouteStub | null;
    /**
     * The first child of the route
     */
    firstChild?: ActivatedRouteStub | null;
    /**
     * The children of the route
     */
    children?: ActivatedRouteStub[] | null;
    /**
     * The configuration of the route
     */
    routeConfig?: Route | null;
}
/**
 * A stub for ActivatedRoute. It behaves almost the same way as the actual ActivatedRoute, exposing a snapshot
 * and observables for the params, query params etc., which are kept in sync.
 *
 * In addition, this stub allows simulating a navigation by changing the params, the query params, the fragment, etc.
 * When that happens, the snapshot is modified, then the relevant observables emit the new values.
 *
 * There are some things that don't really work the same way as the real ActivatedRoute though:
 * - the handling of the firstChild and of the children is entirely under the tester's responsibility. Setting the parent
 *   of a route stub does not add this route to the children of its parent, for example.
 * - when changing the params, query params, fragment, etc., their associated observable emits unconditionally, instead of
 *   first checking if the value is actually different from before. It's thus the responsibility of the tester to not
 *   change the values if they're the same as before.
 * - the params, paramMap, queryParams and queryParamMap objects of the route snapshot change when params or query params are set
 *   on the stub route. So if the code keeps a reference to params or paramMaps, it won't see the changes.
 */
export declare class ActivatedRouteStub extends ActivatedRoute {
    private _firstChild;
    private _children;
    private readonly paramsSubject;
    private readonly queryParamsSubject;
    private readonly dataSubject;
    private readonly fragmentSubject;
    private readonly urlSubject;
    private readonly titleSubject;
    private _parent;
    private _root;
    private _pathFromRoot;
    /**
     * Constructs a new instance, based on the given options.
     * If an option is not provided (or if no option is provided at all), then the route has a default value for this option
     * (empty parameters for example, null fragment, etc.)
     * If no parent is passed, then this route has no parent and is thus set as the root. Otherwise, the root and the path
     * from root are created based on the root and path from root of the given parent route.
     */
    constructor(options?: ActivatedRouteStubOptions);
    get root(): ActivatedRouteStub;
    get parent(): ActivatedRouteStub | null;
    get pathFromRoot(): Array<ActivatedRouteStub>;
    get firstChild(): ActivatedRouteStub | null;
    get children(): Array<ActivatedRouteStub>;
    get routeConfig(): Route | null;
    /**
     * Triggers a navigation with the given new parameters. All the other parts (query params etc.) stay as they are.
     * This is a shortcut to `triggerNavigation` that can be used to only change the parameters.
     */
    setParams(params: Params): void;
    /**
     * Triggers a navigation with the given new parameter. The other parameters, as well as all the other parts (query params etc.)
     * stay as they are.
     * This is a shortcut to `triggerNavigation` that can be used to only change one parameter.
     */
    setParam(name: string, value: string): void;
    /**
     * Triggers a navigation with the given new query parameters. All the other parts (params etc.) stay as the are.
     * This is a shortcut to `triggerNavigation` that can be used to only change the query parameters.
     */
    setQueryParams(queryParams: Params): void;
    /**
     * Triggers a navigation with the given new parameter. The other query parameters, as well as all the other parts (params etc.)
     * stay as the are.
     * This is a shortcut to `triggerNavigation` that can be used to only change one query parameter.
     */
    setQueryParam(name: string, value: string): void;
    /**
     * Triggers a navigation with the given new data. The other parameters, as well as all the other parts (params etc.)
     * stay as the are.
     * This is a shortcut to `triggerNavigation` that can be used to only change the data.
     */
    setData(data: Data): void;
    /**
     * Triggers a navigation with the given new data item. The other data, as well as all the other parts (params etc.)
     * stay as the are.
     * This is a shortcut to `triggerNavigation` that can be used to only change one data item.
     */
    setDataItem(name: string, value: unknown): void;
    /**
     * Triggers a navigation with the given new title. The other parameters, as well as all the other parts (params etc.)
     * stay as the are.
     * This is a shortcut to `triggerNavigation` that can be used to only change the title.
     */
    setTitle(title: string | undefined): void;
    /**
     * Triggers a navigation with the given new fragment. The other parts (params etc.)  stay as the are.
     * This is a shortcut to `triggerNavigation` that can be used to only change the fragment.
     */
    setFragment(fragment: string | null): void;
    /**
     * Triggers a navigation with the given new url. The other parts (params etc.)  stay as the are.
     * This is a shortcut to `triggerNavigation` that can be used to only change the url.
     */
    setUrl(url: Array<UrlSegment>): void;
    /**
     * Triggers a navigation based on the given options. If an option is undefined or null, it's ignored. Except for fragment, which is only
     * ignored if it's undefined, because null is a valid value for a fragment.
     *
     * The non-ignored values are used to change the snapshot of the route. Once the snapshot has been modified,
     * the observables corresponding to the updated parts emit the new value.
     *
     * So, setting params and query params will make the params and queryParams observables emit, but not the fragment, data and
     * url observables for example. This is consistent to how the router behaves.
     *
     * Note: since the title of a route can become undefined, in order to be able to distinguish between a navigation which leaves the title
     * as it is and a navigation that sets the title to undefined, a wrapper object is used for the title. So
     *
     * - `triggerNavigation({ params:... })` leaves the title as is because it's undefined in the options
     * - `triggerNavigation({ title: { value: 'test' } })` sets the title to 'test'
     * - `triggerNavigation({ title: { value: undefined } })` sets the title to undefined
     */
    triggerNavigation(options: {
        params?: Params;
        queryParams?: Params;
        fragment?: string | null;
        data?: Data | null;
        title?: {
            value: string | undefined;
        } | null;
        url?: Array<UrlSegment> | null;
    }): void;
    toString(): string;
}
/**
 * Creates a new ActivatedRouteStub, by calling its constructor.
 */
export declare function stubRoute(options?: ActivatedRouteStubOptions): ActivatedRouteStub;
